#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class TrixColor : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int periodLong = 10; // Default setting for PeriodLong
            private int periodShort = 5; // Default setting for PeriodShort
			private DataSeries trix;
			private DataSeries trix2;
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
          	Add (new Plot(Color.Blue, PlotStyle.Line,"TrixSlow"));
			Add (new Plot(Color.Blue, PlotStyle.Line,"TrixFast"));
            Overlay				= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			if (CurrentBar<periodLong) return;
			

			EMA tripleEma = EMA(EMA(EMA(Inputs[0], periodLong), periodLong), periodLong);
			TrixSlow.Set(100 * ((tripleEma[0] - tripleEma[1]) / tripleEma[0]));
			
			if (Rising(TrixSlow))
			{
				PlotColors[1][0] = Color.Green;
			}
			else if (Falling(TrixSlow))
			{
				PlotColors[1][0] = Color.Red;
			}
			else 
			{
				PlotColors[1][0] = Color.Yellow;
			}
			
			
            EMA tripleEma2 = EMA(EMA(EMA(Inputs[0], periodShort), periodShort), periodShort);
			TrixFast.Set(100 * ((tripleEma2[0] - tripleEma2[1]) / tripleEma2[0]));
			
			if (Rising(TrixFast))
			{
				PlotColors[0][0] = Color.Green;
			}
			else if (Falling(TrixFast))
			{
				PlotColors[0][0] = Color.Red;
			}
           	else
            {
				PlotColors[0][0] = Color.Yellow;
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries TrixFast
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries TrixSlow
        {
            get { return Values[1]; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int PeriodLong
        {
            get { return periodLong; }
            set { periodLong = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int PeriodShort
        {
            get { return periodShort; }
            set { periodShort = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private TrixColor[] cacheTrixColor = null;

        private static TrixColor checkTrixColor = new TrixColor();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public TrixColor TrixColor(int periodLong, int periodShort)
        {
            return TrixColor(Input, periodLong, periodShort);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public TrixColor TrixColor(Data.IDataSeries input, int periodLong, int periodShort)
        {
            if (cacheTrixColor != null)
                for (int idx = 0; idx < cacheTrixColor.Length; idx++)
                    if (cacheTrixColor[idx].PeriodLong == periodLong && cacheTrixColor[idx].PeriodShort == periodShort && cacheTrixColor[idx].EqualsInput(input))
                        return cacheTrixColor[idx];

            lock (checkTrixColor)
            {
                checkTrixColor.PeriodLong = periodLong;
                periodLong = checkTrixColor.PeriodLong;
                checkTrixColor.PeriodShort = periodShort;
                periodShort = checkTrixColor.PeriodShort;

                if (cacheTrixColor != null)
                    for (int idx = 0; idx < cacheTrixColor.Length; idx++)
                        if (cacheTrixColor[idx].PeriodLong == periodLong && cacheTrixColor[idx].PeriodShort == periodShort && cacheTrixColor[idx].EqualsInput(input))
                            return cacheTrixColor[idx];

                TrixColor indicator = new TrixColor();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.PeriodLong = periodLong;
                indicator.PeriodShort = periodShort;
                Indicators.Add(indicator);
                indicator.SetUp();

                TrixColor[] tmp = new TrixColor[cacheTrixColor == null ? 1 : cacheTrixColor.Length + 1];
                if (cacheTrixColor != null)
                    cacheTrixColor.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheTrixColor = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.TrixColor TrixColor(int periodLong, int periodShort)
        {
            return _indicator.TrixColor(Input, periodLong, periodShort);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.TrixColor TrixColor(Data.IDataSeries input, int periodLong, int periodShort)
        {
            return _indicator.TrixColor(input, periodLong, periodShort);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.TrixColor TrixColor(int periodLong, int periodShort)
        {
            return _indicator.TrixColor(Input, periodLong, periodShort);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.TrixColor TrixColor(Data.IDataSeries input, int periodLong, int periodShort)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.TrixColor(input, periodLong, periodShort);
        }
    }
}
#endregion
